Enlightenment CVS committal

Author  : xcomputerman
Project : e17
Module  : apps/entrance

Dir     : e17/apps/entrance/src/client


Modified Files:
        entrance_auth.c entrance_auth.h entrance_session.c 
        entrance_session.h main.c 


Log Message:
Do not set display environment variable until before the session is
launched. This should fix the issue with Xnest not displaying.

===================================================================
RCS file: /cvsroot/enlightenment/e17/apps/entrance/src/client/entrance_auth.c,v
retrieving revision 1.15
retrieving revision 1.16
diff -u -3 -r1.15 -r1.16
--- entrance_auth.c     19 Apr 2004 05:15:50 -0000      1.15
+++ entrance_auth.c     1 May 2004 20:44:52 -0000       1.16
@@ -326,6 +326,9 @@
    setenv("USER", e->pw->pw_name, 1);
    setenv("LOGNAME", e->pw->pw_name, 1);
 
+   if (e->display)
+      setenv("DISPLAY", e->display, 1);
+
    size = (strlen(_PATH_MAILDIR) + strlen(e->pw->pw_name) + 2);
    mail = (char *) malloc(sizeof(char) * size);
    snprintf(mail, size, "%s/%s", _PATH_MAILDIR, e->pw->pw_name);
===================================================================
RCS file: /cvsroot/enlightenment/e17/apps/entrance/src/client/entrance_auth.h,v
retrieving revision 1.9
retrieving revision 1.10
diff -u -3 -r1.9 -r1.10
--- entrance_auth.h     5 Apr 2004 21:28:35 -0000       1.9
+++ entrance_auth.h     1 May 2004 20:44:52 -0000       1.10
@@ -58,6 +58,7 @@
    char user[PATH_MAX];
    char pass[PATH_MAX];
    char **env;
+   char *display;
 };
 typedef struct _Entrance_Auth Entrance_Auth;
 
===================================================================
RCS file: /cvsroot/enlightenment/e17/apps/entrance/src/client/entrance_session.c,v
retrieving revision 1.51
retrieving revision 1.52
diff -u -3 -r1.17 -r1.18
--- entrance_session.h  25 Mar 2004 06:44:52 -0000      1.17
+++ entrance_session.h  1 May 2004 20:44:52 -0000       1.18
@@ -25,6 +25,7 @@
  */
 struct _Entrance_Session
 {
+   char *display;               /* The display the session is running on */
    char *session;               /* the current session in context */
    Ecore_Evas *ee;              /* the ecore_evas */
    Evas_Object *edje;           /* the main theme edje */
@@ -37,7 +38,7 @@
 
 typedef struct _Entrance_Session Entrance_Session;
 
-Entrance_Session *entrance_session_new(const char *config);
+Entrance_Session *entrance_session_new(const char *config, char *display);
 void entrance_session_ecore_evas_set(Entrance_Session * e, Ecore_Evas * ee);
 void entrance_session_free(Entrance_Session * e);
 void entrance_session_run(Entrance_Session * e);
===================================================================
RCS file: /cvsroot/enlightenment/e17/apps/entrance/src/client/main.c,v
retrieving revision 1.50
retrieving revision 1.51
diff -u -3 -r1.50 -r1.51
--- main.c      22 Apr 2004 16:52:20 -0000      1.50
+++ main.c      1 May 2004 20:44:52 -0000       1.51
@@ -660,9 +660,10 @@
    }
 
    if (!entrance_ipc_init(server_pid))
-      return -1;
+      return -1; 
+
+   session = entrance_session_new(config, display);
 
-   session = entrance_session_new(config);
    if (config)
       free(config);
 




-------------------------------------------------------
This SF.Net email is sponsored by: Oracle 10g
Get certified on the hottest thing ever to hit the market... Oracle 10g. 
Take an Oracle 10g class now, and we'll give you the exam FREE. 
http://ads.osdn.com/?ad_id=3149&alloc_id=8166&op=click
_______________________________________________
enlightenment-cvs mailing list
[EMAIL PROTECTED]
https://lists.sourceforge.net/lists/listinfo/enlightenment-cvs

Reply via email to
diff -u -3 -r1.51 -r1.52
--- entrance_session.c  22 Apr 2004 16:52:20 -0000      1.51
+++ entrance_session.c  1 May 2004 20:44:52 -0000       1.52
@@ -27,12 +27,13 @@
 
 /**
  * entrance_session_new: allocate a new  Entrance_Session
  * @param config - parse this config file instead of the normal system one
  * @return a valid Entrance_Session
  * Also Allocates the auth, and parse the config struct 
  */
 Entrance_Session *
-entrance_session_new(const char *config)
+entrance_session_new(const char *config, char *display)
 {
    Entrance_Session *e;
    char *db;
@@ -46,7 +47,9 @@
    memset(e, 0, sizeof(struct _Entrance_Session));
 
    openlog("entrance", LOG_NOWAIT, LOG_DAEMON);
+   e->display = display;
    e->auth = entrance_auth_new();
+   e->auth->display = display;
    e->config = entrance_config_parse(db);
    if (!e->config)
    {
@@ -27,12 +27,13 @@
 /**
  * entrance_session_new: allocate a new  Entrance_Session
- * @param config - parse this config file instead of the normal system one
+ * @param config Parse this config file instead of the normal system one
+ * @param config The display this session will be running on
  * @return a valid Entrance_Session
  * Also Allocates the auth, and parse the config struct 
===================================================================
RCS file: /cvsroot/enlightenment/e17/apps/entrance/src/client/entrance_session.h,v
retrieving revision 1.17
retrieving revision 1.18